package com.sundot.airport.system.service;

import java.util.List;

import com.sundot.airport.system.domain.BaseSeizeCategory;

/**
 * 查获物品分类Service接口
 *
 * @author ruoyi
 * @date 2025-07-08
 */
public interface IBaseSeizeCategoryService {
    /**
     * 查询查获物品分类
     *
     * @param id 查获物品分类主键
     * @return 查获物品分类
     */
    public BaseSeizeCategory selectBaseSeizeCategoryById(Long id);

    /**
     * 查询查获物品分类列表
     *
     * @param baseSeizeCategory 查获物品分类
     * @return 查获物品分类集合
     */
    public List<BaseSeizeCategory> selectBaseSeizeCategoryList(BaseSeizeCategory baseSeizeCategory);

    /**
     * 新增查获物品分类
     *
     * @param baseSeizeCategory 查获物品分类
     * @return 结果
     */
    public int insertBaseSeizeCategory(BaseSeizeCategory baseSeizeCategory);

    /**
     * 修改查获物品分类
     *
     * @param baseSeizeCategory 查获物品分类
     * @return 结果
     */
    public int updateBaseSeizeCategory(BaseSeizeCategory baseSeizeCategory);

    /**
     * 批量删除查获物品分类
     *
     * @param ids 需要删除的查获物品分类主键集合
     * @return 结果
     */
    public int deleteBaseSeizeCategoryByIds(Long[] ids);

    /**
     * 删除查获物品分类信息
     *
     * @param id 查获物品分类主键
     * @return 结果
     */
    public int deleteBaseSeizeCategoryById(Long id);

    /**
     * 查询查获物品分类树形结构
     *
     * @param baseSeizeCategory 查获物品分类
     * @return 树结构列表
     */
    public List<BaseSeizeCategory> selectBaseSeizeCategoryListTree(BaseSeizeCategory baseSeizeCategory);

    /**
     * 构建前端所需要树结构
     *
     * @param list 列表
     * @return 树结构列表
     */
    public List<BaseSeizeCategory> buildTree(List<BaseSeizeCategory> list);
}
